<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>About</name>
    <message>
        <location filename="../qml/About.qml" line="27"/>
        <source>About %1</source>
        <translation>關於 %1</translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="46"/>
        <source>Information</source>
        <translation>資訊</translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="69"/>
        <source>Version %1</source>
        <translation>版本 %1</translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="73"/>
        <source>Using Qt %1</source>
        <translation>使用 Qt %1</translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="87"/>
        <source>Webcam capture application.</source>
        <translation>網路攝影機抓取應用程式。</translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="90"/>
        <source>A simple webcam application for picture and video capture.</source>
        <translation>一個簡單的網路攝影機應用程式，抓取圖片與視訊。</translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="103"/>
        <source>Thanks!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="79"/>
        <source>Website</source>
        <translation>網站</translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="115"/>
        <source>License</source>
        <translation>授權</translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="126"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>AddMedia</name>
    <message>
        <location filename="../qml/AddMedia.qml" line="28"/>
        <source>Add new media</source>
        <translation>新增新媒體</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="65"/>
        <source>Description</source>
        <translation>說明</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="72"/>
        <source>Insert media description</source>
        <translation>插入媒體說明</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="79"/>
        <source>Media file</source>
        <translation>媒體檔案</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="87"/>
        <source>Select media file</source>
        <translation>選擇媒體檔案</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="94"/>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="116"/>
        <source>Ok</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="142"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="153"/>
        <source>Choose the file to add as media</source>
        <translation>選擇要增加媒體的檔案</translation>
    </message>
</context>
<context>
    <name>AudioConfig</name>
    <message>
        <location filename="../qml/AudioConfig.qml" line="116"/>
        <source>Outputs</source>
        <translation>輸出</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="119"/>
        <source>Select the output device for audio playing</source>
        <translation>選擇用於播放音訊的輸出設備</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="133"/>
        <source>Inputs</source>
        <translation>輸入</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="135"/>
        <source>Select the device for audio capturing</source>
        <translation>選擇用於音訊擷取的裝置</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="192"/>
        <location filename="../qml/AudioConfig.qml" line="294"/>
        <source>Silence</source>
        <translation>靜音</translation>
    </message>
</context>
<context>
    <name>AudioInfo</name>
    <message>
        <location filename="../qml/AudioInfo.qml" line="168"/>
        <source>Description</source>
        <translation>說明</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="183"/>
        <location filename="../qml/AudioInfo.qml" line="190"/>
        <source>Device description</source>
        <translation>裝置說明</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="198"/>
        <location filename="../qml/AudioInfo.qml" line="213"/>
        <location filename="../qml/AudioInfo.qml" line="220"/>
        <source>Device id</source>
        <translation>裝置 id</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="235"/>
        <source>Sample Format</source>
        <translation>樣本格式</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="261"/>
        <source>Channels</source>
        <translation>頻道</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="287"/>
        <source>Sample Rate</source>
        <translation>採樣率</translation>
    </message>
</context>
<context>
    <name>ConfigBar</name>
    <message>
        <location filename="../qml/ConfigBar.qml" line="44"/>
        <source>Output</source>
        <translation>輸出</translation>
    </message>
    <message>
        <location filename="../qml/ConfigBar.qml" line="48"/>
        <source>General Options</source>
        <translation>一般選項</translation>
    </message>
    <message>
        <location filename="../qml/ConfigBar.qml" line="52"/>
        <source>Plugins Configs</source>
        <translation>外掛配置</translation>
    </message>
    <message>
        <location filename="../qml/ConfigBar.qml" line="56"/>
        <source>Updates</source>
        <translation>更新</translation>
    </message>
</context>
<context>
    <name>EffectBar</name>
    <message>
        <location filename="../qml/EffectBar.qml" line="121"/>
        <source>Search effect...</source>
        <translation>搜尋效果…</translation>
    </message>
    <message>
        <location filename="../qml/EffectBar.qml" line="167"/>
        <source>None</source>
        <translation>無</translation>
    </message>
</context>
<context>
    <name>EffectConfig</name>
    <message>
        <location filename="../qml/EffectConfig.qml" line="95"/>
        <location filename="../qml/EffectConfig.qml" line="102"/>
        <source>Plugin id</source>
        <translation>外掛程式 ID</translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="82"/>
        <source>Description</source>
        <translation>說明</translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="89"/>
        <source>Plugin description</source>
        <translation>外掛程式說明</translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="118"/>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="118"/>
        <source>Add</source>
        <translation>新增</translation>
    </message>
</context>
<context>
    <name>GeneralConfig</name>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="38"/>
        <source>Play webcam on start</source>
        <translation>在開始時播放網路攝影機</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="44"/>
        <source>Enable advanced effects mode</source>
        <translation>啟用進階效果模式</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="50"/>
        <source>Frameworks &amp; libraries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="60"/>
        <source>Video capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="70"/>
        <source>Desktop capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="80"/>
        <source>Audio capture/play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="90"/>
        <source>Video convert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="100"/>
        <source>Audio convert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="110"/>
        <source>Video output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="120"/>
        <source>Video output convert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="130"/>
        <source>Video playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="140"/>
        <source>Video record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="150"/>
        <source>Root method</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaBar</name>
    <message>
        <location filename="../qml/MediaBar.qml" line="62"/>
        <source>No webcams found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaConfig</name>
    <message>
        <location filename="../qml/MediaConfig.qml" line="53"/>
        <source>Description</source>
        <translation>說明</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="60"/>
        <source>Insert media description</source>
        <translation type="unfinished">插入媒體說明</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="67"/>
        <source>Media file</source>
        <translation type="unfinished">媒體檔案</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="74"/>
        <source>Select media file</source>
        <translation type="unfinished">選擇媒體檔案</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="89"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="98"/>
        <source>Remove</source>
        <translation type="unfinished">移除</translation>
    </message>
</context>
<context>
    <name>OutputConfig</name>
    <message>
        <location filename="../qml/OutputConfig.qml" line="40"/>
        <source>Virtual camera</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PhotoWidget</name>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="36"/>
        <source>%1 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="57"/>
        <source>Now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="81"/>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="81"/>
        <source>Shot!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="112"/>
        <source>Use flash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PluginConfig</name>
    <message>
        <location filename="../qml/PluginConfig.qml" line="91"/>
        <source>Use this page for configuring the plugins search paths.&lt;br /&gt;&lt;b&gt;Don&apos;t touch nothing unless you know what you are doing&lt;/b&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="96"/>
        <source>Extra search paths</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="104"/>
        <source>Search plugins in subfolders.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="114"/>
        <source>Add</source>
        <translation type="unfinished">新增</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="122"/>
        <source>Remove</source>
        <translation type="unfinished">移除</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="159"/>
        <source>Search path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="166"/>
        <source>Plugins list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="174"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="185"/>
        <source>Disable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="185"/>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="255"/>
        <source>Plugin path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="267"/>
        <source>Add plugins search path</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/clioptions.cpp" line="32"/>
        <source>Webcam capture application.</source>
        <translation type="unfinished">網路攝影機抓取應用程式。</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="36"/>
        <source>Load settings from PATH. If PATH is empty, load configs from application directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="44"/>
        <source>Semi-colon separated list of paths to search the Qml interface.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="53"/>
        <source>Search in the specified plugins paths recursively.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="59"/>
        <source>Semi-colon separated list of paths to search for plugins.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="66"/>
        <source>Semi-colon separated list of paths to avoid loading.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecordBar</name>
    <message>
        <location filename="../qml/RecordBar.qml" line="100"/>
        <source>Search format...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecordConfig</name>
    <message>
        <location filename="../qml/RecordConfig.qml" line="70"/>
        <source>Video %1.%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="87"/>
        <source>Stop recording video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="90"/>
        <location filename="../qml/RecordConfig.qml" line="123"/>
        <source>Start recording video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="98"/>
        <source>Description</source>
        <translation type="unfinished">說明</translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="105"/>
        <source>Insert format description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="188"/>
        <source>Save video as...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Recording</name>
    <message>
        <location filename="../../src/recording.cpp" line="577"/>
        <source>Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="578"/>
        <source>Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="579"/>
        <source>Subtitle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="634"/>
        <location filename="../../src/recording.cpp" line="800"/>
        <source>audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="635"/>
        <location filename="../../src/recording.cpp" line="801"/>
        <source>video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="636"/>
        <location filename="../../src/recording.cpp" line="802"/>
        <source>subtitle</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdatesConfig</name>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="67"/>
        <source>Notify about new versions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="77"/>
        <source>Check new versions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="85"/>
        <source>Daily</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="89"/>
        <source>Every two days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="93"/>
        <source>Weekly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="97"/>
        <source>Every two weeks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="101"/>
        <source>Monthly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="105"/>
        <source>Never</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="116"/>
        <source>Last updated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="137"/>
        <source>Your version of %1 is outdated. Latest version is &lt;b&gt;%2&lt;/b&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="143"/>
        <source>Upgrade Now!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="159"/>
        <source>Thanks for using a &lt;b&gt;development version&lt;/b&gt;!&lt;br /&gt;It will be very helpful if you can report any bug and suggestions you have.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="164"/>
        <source>Report a Bug</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="172"/>
        <source>Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="111"/>
        <location filename="../qml/main.qml" line="616"/>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="650"/>
        <source>Take a photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="252"/>
        <source>Picture %1.%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="71"/>
        <source>New version available!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="72"/>
        <source>Download %1 %2 NOW!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="107"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="570"/>
        <source>Go back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="624"/>
        <source>Configure sources</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="637"/>
        <source>Configure audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="664"/>
        <source>Record video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="678"/>
        <source>Configure Effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="691"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="704"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="261"/>
        <source>Save photo as...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
